@@ -33,6 +33,7 @@
 #' \dontrun{
 #'   abn.version("system")
 #' }
+#' @keywords internal
 abn.version <- function(what=c('abn','system')) {
   what <- match.arg(what)
   if (what %in% 'system') {
@@ -65,6 +66,7 @@ abn.version <- function(what=c('abn','system')) {
 #' @examples
 #' library(abn)
 #' @keywords internal
+#' @returns Prints startup message to the console
 ".onAttach" <- function (lib, pkg) {
   packageStartupMessage(abn.version()$version.string," is loaded.\nTo cite the package 'abn' in publications call: citation('abn').")
 }
@@ -72,6 +74,7 @@ abn.version <- function(what=c('abn','system')) {
 #' @title Recursive string splitting
 #' @description Internal function that call multiple times strsplit() and remove space
 #' @keywords internal
+#' @returns A vector of strings
 #' @export
 strsplits <- function(x, splits, ...) {
     for (split in splits) {
@@ -86,6 +89,7 @@ strsplits <- function(x, splits, ...) {
 #' f have to start with ~ terms are entries of name terms are separated by + term1 | term2 indicates
 #' col(term1) row(term2) puts a 1 term1 | term2:term3: ... : is used as a sep . = all terms in name
 #' @keywords internal
+#' @returns A square matrix
 #' @export
 formula_abn <- function(f, name) {
 
@@ -201,8 +205,10 @@ formula_abn <- function(f, name) {
 #' @param data.dists list specifying each columns distribution type. Names correspond to column names and values must be one of "gaussian", "binomial", "poisson", "multinomial".
 #' @param group.var not yet implemented
 #'
-#' @return list of sums of each distribution types (abbreviated) as names.
+#' @return list of indexes for each distribution type
 #' @importFrom stats complete.cases
+#' @returns a list of the indexes for each distribution type
+#' @keywords internal
 check.valid.data <- function(data.df = NULL, data.dists = NULL, group.var = NULL) {
 
     ## check data is in a data.frame
@@ -312,6 +318,7 @@ check.valid.data <- function(data.df = NULL, data.dists = NULL, group.var = NULL
 #' @param group.var not yet implemented
 #'
 #' @return dag as named square matrix
+#' @keywords internal
 check.valid.dag <- function(dag = NULL, data.df = NULL, is.ban.matrix = FALSE, group.var = NULL) {
   if (!is.null(data.df) && !inherits(data.df, "data.frame")){
     stop("Invalid argument for data.df provided. Must be NULL or of class data.frame.")
@@ -405,6 +412,7 @@ check.valid.dag <- function(dag = NULL, data.df = NULL, is.ban.matrix = FALSE, g
 #' @param group.var not yet implemented
 #'
 #' @return numeric vector of max number of parents per variable
+#' @keywords internal
 check.valid.parents <- function(data.df = NULL, max.parents = NULL, group.var = NULL) {
   ## Stop if data.df is not provided
   if (is.null(data.df)){
@@ -414,8 +422,6 @@ check.valid.parents <- function(data.df = NULL, max.parents = NULL, group.var =
   ## have a grouping variable so temporarily drop this from data.df - LOCAL TO THIS FUNCTION ONLY
   if (!is.null(group.var)) {
     data.df <- check.valid.groups(group.var = group.var, data.df = data.df)[["data.df"]]
-  } else {
-    # TODO: Take care of group.var
   }
 
   if (is.numeric(max.parents)){
@@ -483,6 +489,7 @@ check.valid.parents <- function(data.df = NULL, max.parents = NULL, group.var =
 #' @param group.var not yet implemented
 #'
 #' @return integer vector of column indexes of valid nodes in data.df
+#' @keywords internal
 check.which.valid.nodes <- function(data.df = NULL, which.nodes = NULL, group.var = NULL) {
     ## have a grouping variable so temporarily drop this from data.df - LOCAL TO THIS FUNCTION ONLY
     if (!is.null(group.var)) {
@@ -510,6 +517,7 @@ check.which.valid.nodes <- function(data.df = NULL, which.nodes = NULL, group.va
 #' @param verbose when TRUE additional information is printed. Defaults to FALSE.
 #'
 #' @return list with data.df, indexes of variables to which the grouping should be applied to and the associated group for each observation as integer.
+#' @keywords internal
 check.valid.groups <- function(group.var=NULL, data.df=NULL, cor.vars=NULL, verbose = FALSE) {
   # No data no checks.
   if (is.null(data.df)){
@@ -547,7 +555,7 @@ check.valid.groups <- function(group.var=NULL, data.df=NULL, cor.vars=NULL, verb
     stop("name of cor.vars does not match any of those in data.df")
   }
   if (group.var %in% cor.vars) {
-    stop("group.var is among the cor.vars.") # TODO: consider to relax this.
+    stop("group.var is among the cor.vars.")
   }
 
   ## get group id data
@@ -588,6 +596,7 @@ check.valid.groups <- function(group.var=NULL, data.df=NULL, cor.vars=NULL, verb
 #' @param verbose when TRUE additional information is printed. Defaults to FALSE.
 #'
 #' @return list with all control arguments with respect to the method but with new values.
+#' @keywords internal
 check.valid.buildControls <- function(control, method = "bayes", verbose = FALSE) {
   ctrl.basic <- build.control(method = method)
   if (is.null(control)) {
@@ -604,41 +613,7 @@ check.valid.buildControls <- function(control, method = "bayes", verbose = FALSE
   }
 
   # check if keys are ok
-  allowed_list_names <- c("method",
-                          "max.mode.error",
-                          "mean",
-                          "prec",
-                          "loggam.shape",
-                          "loggam.inv.scale",
-                          "max.iters",
-                          "epsabs",
-                          "error.verbose",
-                          "trace",
-                          "epsabs.inner",
-                          "max.iters.inner",
-                          "finite.step.size",
-                          "hessian.params",
-                          "max.iters.hessian",
-                          "max.hessian.error",
-                          "factor.brent",
-                          "maxiters.hessian.brent",
-                          "num.intervals.brent",
-                          "n.grid",
-                          "ncores",
-                          "max.irls",
-                          "tol",
-                          "tolPwrss",
-                          "check.rankX",
-                          "check.scaleX",
-                          "check.conv.grad",
-                          "check.conv.singular",
-                          "check.conv.hess",
-                          "xtol_abs",
-                          "ftol_abs",
-                          "trace.mblogit",
-                          "catcov.mblogit",
-                          "epsilon",
-                          "seed")
+  allowed_list_names <- names(formals(build.control))
   if(any(!(names(ctrl.new) %in% allowed_list_names))) {
     stop("Unknown control parameter(s).")
   } else if(any(!(names(ctrl.new) %in% names(build.control(method=method))))) {
@@ -646,7 +621,6 @@ check.valid.buildControls <- function(control, method = "bayes", verbose = FALSE
     # ctrl <- ctrl.basic[which(!(names(build.control(method=method)) %in% names(ctrl.new)))] # ignore them further down in collecting list for return
   }
 
-  # TODO: Add more checks here for the individual control parameters.
   # check catcov.mblogit
   possible_catcov.mblogit <- c("free", "diagonal", "single")
   if (!is.null(ctrl.new[["catcov.mblogit"]])) {
@@ -660,28 +634,51 @@ check.valid.buildControls <- function(control, method = "bayes", verbose = FALSE
       stop("'max.mode.error' is a % and must be [0,100]!")
     }
   }
+
   # check ncores
   if (!is.null(ctrl.new[["ncores"]])) {
-    if (method != "mle") {
-      warning("Multithreading is currently only implemented for method='mle'. I'm ignoring 'ncores' and continue with a single core.")
+    # Prepare multithreading
+    if (ctrl.new[["ncores"]] == -1) {
+      # all but one
+      ctrl.new[["ncores"]] <-  parallel::detectCores() - 1   # if ncores==0 (here or set), single threaded.
+      if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
+    } else if (ctrl.new[["ncores"]] > 1) {
+      ctrl.new[["ncores"]] <- min(ctrl.new[["ncores"]], parallel::detectCores())  # restrict in case of overoptimisitic setting.
+      if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
+    } else if (ctrl.new[["ncores"]] == 1 | ctrl.new[["ncores"]] == 0) {
       ctrl.new[["ncores"]] <- 1
+      if(verbose){message("Running in single core mode.")}
     } else {
-      # Prepare multithreading
-      if (ctrl.new[["ncores"]] == -1) {
-        # all but one
-        ctrl.new[["ncores"]] <-  parallel::detectCores() - 1   # if ncores==0 (here or set), single threaded.
-        if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
-      } else if (ctrl.new[["ncores"]] > 1) {
-        ctrl.new[["ncores"]] <- min(ctrl.new[["ncores"]], parallel::detectCores())  # restrict in case of overoptimisitic setting.
-        if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
-      } else if (ctrl.new[["ncores"]] == 1 | ctrl.new[["ncores"]] == 0) {
-        ctrl.new[["ncores"]] <- 1
-        if(verbose){message("Running in single core mode.")}
+      stop(paste("Argument 'ncores' from build.control(ncores=...) is invalid. It must be larger or equal -1 and smaller or equal", parallel::detectCores()))
+    }
+
+    # checking cluster type if ncores > 1
+    if (ctrl.new[["ncores"]] > 1) {
+      if (!is.null(ctrl.new[["cluster.type"]])) {
+        if (!(ctrl.new[["cluster.type"]] %in% c("PSOCK", "FORK"))) {
+          stop(paste("'cluster.type' must be one of", deparse(c("PSOCK", "FORK"))))
+        }
+        if (ctrl.new[["cluster.type"]] == "FORK" & Sys.info()[["sysname"]] == "Windows") {
+          warning("FORK cluster type is not supported on Windows. Using PSOCK instead.")
+          ctrl.new[["cluster.type"]] <- "PSOCK"
+        }
+        if (verbose) message(paste0("Using cluster type ", ctrl.new[["cluster.type"]], "."))
       } else {
-        stop(paste("Argument 'ncores' from build.control(ncores=...) is invalid. It must be larger or equal -1 and smaller or equal", parallel::detectCores()))
+        # if cluster type is not specified, set to PSOCK on windows, FORK on unix
+        # default in abn to PSOCK on windows, FORK on unix
+        if (Sys.info()[["sysname"]] == "Windows") {
+          ctrl.new[["cluster.type"]] <- "PSOCK"
+        } else {
+          ctrl.new[["cluster.type"]] <- "FORK"
+        }
       }
+    } else {
+      # if ncores == 1, cluster type is ignored
+      ctrl.new[["cluster.type"]] <- NULL
+      if (verbose) message("Running in single core mode. 'cluster.type' is ignored.")
     }
   }
+
   # check seed
   if (!is.null(ctrl.new[["seed"]])) {
     if ((!inherits(ctrl.new[["seed"]], "integer") | ctrl.new[["seed"]] < 0)) {
@@ -718,55 +715,13 @@ check.valid.fitControls <- function(control, method = "bayes", verbose = FALSE)
   }
 
   # check if keys are ok
-  allowed_list_names <- c("method",
-                          "max.mode.error",
-                          "mean",
-                          "prec",
-                          "loggam.shape",
-                          "loggam.inv.scale",
-                          "max.iters",
-                          "epsabs",
-                          "error.verbose",
-                          "trace",
-                          "epsabs.inner",
-                          "max.iters.inner",
-                          "finite.step.size",
-                          "hessian.params",
-                          "max.iters.hessian",
-                          "max.hessian.error",
-                          "factor.brent",
-                          "maxiters.hessian.brent",
-                          "num.intervals.brent",
-                          "min.pdf",
-                          "n.grid",
-                          "std.area",
-                          "marginal.quantiles",
-                          "max.grid.iter",
-                          "marginal.node",
-                          "marginal.param",
-                          "variate.vec",
-                          "ncores",
-                          "max.irls",
-                          "tol",
-                          "tolPwrss",
-                          "check.rankX",
-                          "check.scaleX",
-                          "check.conv.grad",
-                          "check.conv.singular",
-                          "check.conv.hess",
-                          "xtol_abs",
-                          "ftol_abs",
-                          "trace.mblogit",
-                          "catcov.mblogit",
-                          "epsilon",
-                          "seed")
+  allowed_list_names <- names(formals(fit.control))
   if(any(!(names(ctrl.new) %in% allowed_list_names))) {
     stop("Unknown control parameter(s).")
   } else if(any(!(names(ctrl.new) %in% names(fit.control(method=method))))) {
     warning(paste("Control parameters provided that are not used with method", method, "are ignored."))
   }
 
-  # TODO: Add more checks here for the individual control parameters.
   # check catcov.mblogit
   possible_catcov.mblogit <- c("free", "diagonal", "single")
   if (!is.null(ctrl.new[["catcov.mblogit"]])) {
@@ -795,26 +750,48 @@ check.valid.fitControls <- function(control, method = "bayes", verbose = FALSE)
   }
   # check ncores
   if (!is.null(ctrl.new[["ncores"]])) {
-    if (method != "mle") {
-      warning("Multithreading is currently only implemented for method='mle'. I'm ignoring 'ncores' and continue with a single core.")
+    # Prepare multithreading
+    if (ctrl.new[["ncores"]] == -1) {
+      # all but one
+      ctrl.new[["ncores"]] <-  parallel::detectCores() - 1   # if ncores==0 (here or set), single threaded.
+      if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
+    } else if (ctrl.new[["ncores"]] > 1) {
+      ctrl.new[["ncores"]] <- min(ctrl.new[["ncores"]], parallel::detectCores())  # restrict in case of overoptimisitic setting.
+      if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
+    } else if (ctrl.new[["ncores"]] == 1 | ctrl.new[["ncores"]] == 0) {
       ctrl.new[["ncores"]] <- 1
+      if(verbose){message("Running in single core mode.")}
     } else {
-      # Prepare multithreading
-      if (ctrl.new[["ncores"]] == -1) {
-        # all but one
-        ctrl.new[["ncores"]] <-  parallel::detectCores() - 1   # if ncores==0 (here or set), single threaded.
-        if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
-      } else if (ctrl.new[["ncores"]] > 1) {
-        ctrl.new[["ncores"]] <- min(ctrl.new[["ncores"]], parallel::detectCores())  # restrict in case of overoptimisitic setting.
-        if(verbose){message("Running in parallel with ", ctrl.new[["ncores"]], " cores.")}
-      } else if (ctrl.new[["ncores"]] == 1 | ctrl.new[["ncores"]] == 0) {
-        ctrl.new[["ncores"]] <- 1
-        if(verbose){message("Running in single core mode.")}
+      stop(paste("Argument 'ncores' from fit.control(ncores=...) is invalid. It must be larger or equal -1 and smaller or equal", parallel::detectCores()))
+    }
+
+    # checking cluster type if ncores > 1
+    if (ctrl.new[["ncores"]] > 1) {
+      if (!is.null(ctrl.new[["cluster.type"]])) {
+        if (!(ctrl.new[["cluster.type"]] %in% c("PSOCK", "FORK"))) {
+          stop(paste("'cluster.type' must be one of", deparse(c("PSOCK", "FORK"))))
+        }
+        if (ctrl.new[["cluster.type"]] == "FORK" & Sys.info()[["sysname"]] == "Windows") {
+          warning("FORK cluster type is not supported on Windows. Using PSOCK instead.")
+          ctrl.new[["cluster.type"]] <- "PSOCK"
+        }
+        if (verbose) message(paste0("Using cluster type ", ctrl.new[["cluster.type"]], "."))
       } else {
-        stop(paste("Argument 'ncores' from fit.control(ncores=...) is invalid. It must be larger or equal -1 and smaller or equal", parallel::detectCores()))
+        # if cluster type is not specified, set to PSOCK on windows, FORK on unix
+        # default in abn to PSOCK on windows, FORK on unix
+        if (Sys.info()[["sysname"]] == "Windows") {
+          ctrl.new[["cluster.type"]] <- "PSOCK"
+        } else {
+          ctrl.new[["cluster.type"]] <- "FORK"
+        }
       }
+    } else {
+      # if ncores == 1, cluster type is ignored
+      ctrl.new[["cluster.type"]] <- NULL
+      if (verbose) message("Running in single core mode. 'cluster.type' is ignored.")
     }
   }
+
   # check seed
   if (!is.null(ctrl.new[["seed"]])) {
     if ((!inherits(ctrl.new[["seed"]], "integer") | ctrl.new[["seed"]] < 0)) {
@@ -842,6 +819,7 @@ check.valid.fitControls <- function(control, method = "bayes", verbose = FALSE)
 #' @param data.dists list specifying each columns distribution type. Names correspond to column names and values must be one of "gaussian", "binomial", "poisson", "multinomial".
 #'
 #' @return numeric encoding of distribution corresponding to its list element number in `data.dists`.
+#' @keywords internal
 get.var.types <- function(data.dists = NULL) {
   store <- rep(NA, length(data.dists))
 
@@ -872,6 +850,7 @@ get.var.types <- function(data.dists = NULL) {
 
 #' @title tidy up cache
 #' @keywords internal
+#' @returns list of chache with error indexes removed
 #' @export
 tidy.cache <- function(thecache) {
     if (!is.null(thecache[["error.indexes"]])) {
