@@ -12,7 +12,9 @@
 #' @param INLA.marginals vector - TRUE if INLA used false otherwise
 #' @param iter.max same as \code{max.iters} in \code{\link{fit.control}}. Total number of iterations allowed when estimating the modes in Laplace approximation. Passed to .Call("fit_single_node", ...).
 #' @family Bayes
+#' @returns A named list with "modes", "error.code", "hessian.accuracy", "error.code.desc", "mliknode", "mlik", "mse", "coef", "used.INLA", "marginals".
 #' @importFrom stats sd spline
+#' @keywords internal
 getmarginals <- function(res.list,
                        data.df,dag.m,var.types,max.parents,
                        mean,prec,loggam.shape,loggam.inv.scale,
@@ -55,7 +57,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),
                             as.double(max.hessian.error),
                             as.double(factor.brent),
@@ -114,7 +116,6 @@ if( !is.null(marginal.node)) {## in single node case
           row <- 1;
           mymat <- matrix(data=c(variate.x,rep(NA,3)),ncol=2,byrow=TRUE);colnames(mymat) <- c("x","f(x)");## storage for three rows
           for(betafixed in variate.x){## for each of the three initial points mode +/- one other
-
           marg.res <- .Call("fitabn_marginals",data.df,as.integer(dag.m),as.integer(dim(data.df)[2]),
                             as.integer(var.types),as.integer(max.parents),
                             as.double(mean),as.double(1/sqrt(prec)),as.double(loggam.shape),as.double(1/loggam.inv.scale),
@@ -131,7 +132,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -140,7 +141,7 @@ if( !is.null(marginal.node)) {## in single node case
               );
               #cat("betafixed=",betafixed," gvalue=",marg.res,"\n");
               mymat[row,] <- c(betafixed,marg.res);row <- row+1;
-              }
+          }
               #cat("original points\n");print(mymat);
               gvalue <- mymat[,2];## f(x) values
               big.ok <- small.ok <- FALSE;
@@ -178,7 +179,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -225,7 +226,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -272,7 +273,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -319,7 +320,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -365,7 +366,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -411,7 +412,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -457,7 +458,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -503,7 +504,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -550,7 +551,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -598,7 +599,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -646,7 +647,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -695,7 +696,7 @@ if( !is.null(marginal.node)) {## in single node case
                             as.integer(paramid-1),## C index from 0
                             as.double(res.list$modes[[nodeid]]), ## relevant mode estimates
                             as.double(betafixed), ## value to be evaluated e.g. want f(x) given x - betafixed is x
-                            as.double(res.list[[names(res.list$modes)[nodeid]]]),## mlik for the node
+                            as.double(res.list[["mliknode"]][nodeid]),## mlik for the node
                             as.integer(max.iters.hessian),as.double(max.hessian.error),
                             as.double(factor.brent),
                             as.integer(maxiters.hessian.brent),
@@ -777,6 +778,7 @@ find.next.left.x <- function(mat.xy,g.max,g.factor,x.delta,max.fact.delta){
 }
 
 #' @describeIn find.next.left.x Attempt to find the next x evaluation point using spline extrapolation traversing right from mode.
+#' @return integer
 find.next.right.x <- function(mat.xy,g.max,g.factor,x.delta,max.fact.delta){
 
   xright <- max(mat.xy[,"x"]);## current left hand endpoint
