@@ -23,6 +23,8 @@ test_that("fit.control() works fine", {
 })
 
 test_that("fitAbn() wrapper of 'mle' and 'bayes' works", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   # Gaussian
   df <- airquality[complete.cases(airquality), ]
 
@@ -51,6 +53,8 @@ test_that("fitAbn() wrapper of 'mle' and 'bayes' works", {
 })
 
 test_that("fitAbn() works with DAG as formula statement", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   # using 'ex3.dag.data'
   mydists <- list(b1="binomial",  b2="binomial")
 
@@ -68,6 +72,8 @@ test_that("fitAbn() works with DAG as formula statement", {
 })
 
 test_that("fitAbn() catches wrong arguments.", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   # using 'ex3.dag.data'
   mydists <- list(b1="binomial",  b2="binomial")
 
@@ -85,6 +91,8 @@ test_that("fitAbn() catches wrong arguments.", {
 })
 
 test_that("fitAbn() runs in parallel", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   # Prepare some data
   df <- airquality[complete.cases(airquality), ]
   dist <- list(Ozone="gaussian", Solar.R="gaussian", Wind="gaussian", Temp="gaussian", Month="gaussian", Day="gaussian")
@@ -94,9 +102,19 @@ test_that("fitAbn() runs in parallel", {
   colnames(d) <- rownames(d) <- names(dist)
 
   # test method="bayes"
-  expect_warning({
+  expect_no_error({
     fitAbn(dag=d, data.df=df, data.dists=dist, method="bayes", control = list(ncores = 1))
-  }, regexp = "Multithreading is currently only implemented for method='mle'")
+  })
+  expect_no_error({
+    fitAbn(dag=d, data.df=df, data.dists=dist, method="bayes", control = list(ncores = 0))
+  })
+  expect_error({
+    fitAbn(dag=d, data.df=df, data.dists=dist, method="bayes", control = list(ncores = -2))
+  }, regexp = "Argument 'ncores'")
+  skip_on_cran() # workaround to not overconsume threads on CRAN. This is related to an issue reported for lme4
+  expect_no_error({
+    fitAbn(dag=d, data.df=df, data.dists=dist, method="bayes", control = list(ncores = 2))
+  })
 
   # test method="mle"
   expect_no_error({
@@ -115,10 +133,12 @@ test_that("fitAbn() runs in parallel", {
 })
 
 test_that("fitAbn() works with control arguments", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   mydists <- list(b1="binomial",  b2="binomial")
 
   # Supplying control arguments as direct arguments is deprecated. They should be passed in a list of 'control=list(max.mode.error=0)'
-  expect_no_error(fitAbn(dag=~b1|b2, data.df=ex3.dag.data[,c(1,2)], data.dists=mydists, max.mode.error=0))
+  expect_warning(fitAbn(dag=~b1|b2, data.df=ex3.dag.data[,c(1,2)], data.dists=mydists, max.mode.error=0))
   expect_no_error(fitAbn(dag=~b1|b2, data.df=ex3.dag.data[,c(1,2)], data.dists=mydists, method = "bayes", control=list(max.mode.error=0)))
   expect_warning(fitAbn(dag=~b1|b2, data.df=ex3.dag.data[,c(1,2)], data.dists=mydists, method = "mle", control=list(max.mode.error=0)))
 
@@ -155,14 +175,20 @@ test_that("fitAbn() works with control arguments", {
   mydag["b4","b1"] <- 1; # b4 <- b1
   mydag["p4","g1"] <- 1; # p4 <- g1
 
-  expect_no_error(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists,centre=TRUE, compute.fixed=TRUE,n.grid=100))
+  expect_no_error(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists,centre=TRUE, compute.fixed=TRUE, control=list(n.grid=100)))
   expect_no_error(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "bayes", centre=TRUE, compute.fixed=TRUE, control=list(n.grid=100)))
-  expect_warning(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "mle", centre=TRUE, compute.fixed=TRUE, control=list(n.grid=100)))
+
+  expect_error(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "mle", centre=TRUE, compute.fixed=TRUE, control=list(n.grid=100)))
+  expect_warning(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "mle", centre=TRUE, compute.fixed=FALSE, control=list(n.grid=100)))
+  expect_warning(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "mle", centre=TRUE, control=list(n.grid=100)))
+  expect_no_error(fitAbn(dag=mydag,data.df=mydat,data.dists=mydists, method = "mle", centre=TRUE))
 
   # TODO: make this tests more explicit.
 })
 
 test_that("fitAbn() is backward compatible", {
+  skip_on_cran() # Skipped on CRAN because it requires the INLA package
+
   ## use built-in simulated data set
 
   mydat <- ex0.dag.data[,c("b1","b2","b3","g1","b4","p2","p4")];## take a subset of cols
@@ -385,10 +411,10 @@ test_that("fitabn() works with all distributions, grouping and class abnCache",
   })
   expect_error({
     myres.mle <- fitAbn(object = mp.dag.mle, data.df = df, data.dists = mydists)
-  }, regexp = "`data.df` and `object` provided but can only accept one of them")
+  }, regexp = "'data.df' and 'object' provided but can only accept one of them")
   expect_error({
     myres.mle <- fitAbn(object = mp.dag.mle, data.dists = mydists)
-  }, regexp = "`data.dists` and `object` provided but can only accept one of them")
+  }, regexp = "'data.dists' and 'object' provided but can only accept one of them")
   expect_no_error({
     suppressWarnings({
       myres.mle <- fitAbn(object = mp.dag.mle, method = "mle")
@@ -424,12 +450,12 @@ test_that("fitabn() works with all distributions, grouping and class abnCache",
   })
   expect_error({
     myres.mle <- fitAbn(object = hc.dag.mle, data.df = df, data.dists = mydists)
-  }, regexp = "`data.df` and `object` provided but can only accept one of them")
+  }, regexp = "'data.df' and 'object' provided but can only accept one of them")
   expect_error({
     suppressWarnings({
       myres.mle <- fitAbn(object = hc.dag.mle, data.dists = mydists)
     })
-  }, regexp = "`data.dists` and `object` provided but can only accept one of them")
+  }, regexp = "'data.dists' and 'object' provided but can only accept one of them")
   expect_no_error({
     suppressWarnings({
       myres.mle <- fitAbn(object = hc.dag.mle, method = "mle")
